# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .legacy_guideline import LegacyGuideline
import typing
from .legacy_guideline_connection import LegacyGuidelineConnection
from .guideline_tool_association import GuidelineToolAssociation
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class LegacyGuidelineWithConnectionsAndToolAssociations(UniversalBaseModel):
    """
    A Guideline with its connections and tool associations.
    """

    guideline: LegacyGuideline
    connections: typing.List[LegacyGuidelineConnection]
    tool_associations: typing.List[GuidelineToolAssociation]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
