# This file was auto-generated by Fern from our API Definition.

import typing

SessionStatusDto = typing.Union[
    typing.Literal[
        "acknowledged", "cancelled", "processing", "ready", "typing", "error"
    ],
    typing.Any,
]
