# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .legacy_guideline_invoice_data import LegacyGuidelineInvoiceData
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class LegacyInvoiceData(UniversalBaseModel):
    """
    Contains the relevant invoice data.

    At this point only `guideline` is supported.
    """

    guideline: typing.Optional[LegacyGuidelineInvoiceData] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
