# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import pydantic
from .tool_id import ToolId
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class GuidelineToolAssociation(UniversalBaseModel):
    """
    Represents an association between a Guideline and a Tool, enabling automatic tool invocation
    when the Guideline's conditions are met.
    """

    id: str = pydantic.Field()
    """
    Unique identifier for the association between a tool and a guideline
    """

    guideline_id: str = pydantic.Field()
    """
    Unique identifier for the guideline
    """

    tool_id: ToolId

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
